@@ -106,6 +106,7 @@ impl ConstantRateDuration {
     /// Construct a new `ConstantRateDuration`, where `count`
     /// corresponds to the number of samples and `rate` is the
     /// sampling rate in Hertz.
+    #[must_use]
     pub fn new(count: u64, rate: u64) -> ConstantRateDuration {
         ConstantRateDuration { count, rate }
     }
@@ -125,6 +126,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.as_secs(), 62);
     /// ```
     /// [`subsec_secs`]: ConstantRateDuration::subsec_secs
+    #[must_use]
     pub fn as_secs(&self) -> u64 {
         self.count / self.rate
     }
@@ -143,6 +145,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "01:31:00;0");
     /// assert_eq!(crd.as_mins(), 91);
     /// ```
+    #[must_use]
     pub fn as_mins(&self) -> u64 {
         self.as_secs() / SECS_PER_MIN
     }
@@ -161,6 +164,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "48:00:00;12345");
     /// assert_eq!(crd.as_hours(), 48);
     /// ```
+    #[must_use]
     pub fn as_hours(&self) -> u64 {
         self.as_secs() / SECS_PER_HOUR
     }
@@ -179,6 +183,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "48:00:00;12345");
     /// assert_eq!(crd.as_days(), 2);
     /// ```
+    #[must_use]
     pub fn as_days(&self) -> u64 {
         self.as_secs() / SECS_PER_DAY
     }
@@ -197,6 +202,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "504:00:00;12345");
     /// assert_eq!(crd.as_weeks(), 3);
     /// ```
+    #[must_use]
     pub fn as_weeks(&self) -> u64 {
         self.as_secs() / SECS_PER_WEEK
     }
@@ -215,6 +221,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "00:00:01;12345");
     /// assert_eq!(crd.subsec_samples(), 12345);
     /// ```
+    #[must_use]
     pub fn subsec_samples(&self) -> u64 {
         self.count % self.rate
     }
@@ -234,6 +241,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "00:00:01;24000");
     /// assert_eq!(crd.subsec_nanos(), 500_000_000);
     /// ```
+    #[must_use]
     pub fn subsec_nanos(&self) -> u32 {
         let nanos_as_f64 = self.subsec_secs() * NANOS_PER_SEC;
 
@@ -253,6 +261,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "00:00:01;24000");
     /// assert_eq!(crd.subsec_secs(), 0.5);
     /// ```
+    #[must_use]
     pub fn subsec_secs(&self) -> f64 {
         self.subsec_samples() as f64 / self.rate as f64
     }
@@ -270,6 +279,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "00:01:05;32000");
     /// assert_eq!(crd.submin_secs(), 5);
     /// ```
+    #[must_use]
     pub fn submin_secs(&self) -> u64 {
         self.as_secs() % SECS_PER_MIN
     }
@@ -287,6 +297,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "01:08:00;0");
     /// assert_eq!(crd.subhour_mins(), 8);
     /// ```
+    #[must_use]
     pub fn subhour_mins(&self) -> u64 {
         self.as_mins() % MINS_PER_HOUR
     }
@@ -304,6 +315,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "25:00:00;0");
     /// assert_eq!(crd.subday_hours(), 1);
     /// ```
+    #[must_use]
     pub fn subday_hours(&self) -> u64 {
         self.as_hours() % HOURS_PER_DAY
     }
@@ -321,6 +333,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "216:00:00;0");
     /// assert_eq!(crd.subweek_days(), 2);
     /// ```
+    #[must_use]
     pub fn subweek_days(&self) -> u64 {
         self.as_days() % DAYS_PER_WEEK
     }
@@ -336,6 +349,7 @@ impl ConstantRateDuration {
     /// assert_eq!(crd.to_string(), "00:00:42;0");
     /// assert_eq!(crd.to_duration().as_secs_f64(), 42.0);
     /// ```
+    #[must_use]
     pub fn to_duration(&self) -> Duration {
         Duration::new(self.as_secs(), self.subsec_nanos())
     }
@@ -362,6 +376,11 @@ impl ConstantRateDuration {
     ///   assert!(false);
     /// }
     ///```
+    ///
+    /// # Errors
+    ///
+    /// Will return a `Err(MixedRateDuration)` if the provided
+    /// `ConstantRateDurations` have incommensurate sampling rates.
     pub fn try_add(
         self,
         other: ConstantRateDuration,
@@ -409,6 +428,11 @@ impl ConstantRateDuration {
     ///   assert!(false);
     /// }
     ///```
+    ///
+    /// # Errors
+    ///
+    /// Will return a `Err(MixedRateDuration)` if the provided
+    /// `ConstantRateDurations` have incommensurate sampling rates.
     pub fn try_add_assign(&mut self, crd: ConstantRateDuration) -> Result<(), MixedRateDuration> {
         if self.rate == crd.rate {
             self.count = self
@@ -422,13 +446,13 @@ impl ConstantRateDuration {
         map.insert(self.rate, self.count);
         map.insert(crd.rate, crd.count);
 
-        let mut mrd = MixedRateDuration {
+        let mut mixed_rate_duration = MixedRateDuration {
             duration: Duration::new(0, 0),
             map,
         };
-        mrd.update_duration();
+        mixed_rate_duration.update_duration();
 
-        Err(mrd)
+        Err(mixed_rate_duration)
     }
 
     /// Computes `self - other` returning `Ok(ConstantRateDuration)`
@@ -457,6 +481,11 @@ impl ConstantRateDuration {
     /// let f = ConstantRateDuration::new(48000, 48000);
     /// assert_eq!(e.try_saturating_sub(f), Err(Error::IncommensurateRates));
     ///```
+    ///
+    /// # Errors
+    ///
+    /// Will return an `Error::IncommensurateRates` if the provided
+    /// `ConstantRateDurations` have incommensurate sampling rates.
     pub fn try_saturating_sub(
         self,
         other: ConstantRateDuration,
@@ -505,6 +534,11 @@ impl ConstantRateDuration {
     /// let f = ConstantRateDuration::new(48000, 48000);
     /// assert!(e.try_saturating_sub(f).is_err());
     ///```
+    ///
+    /// # Errors
+    ///
+    /// Will return an `Error::IncommensurateRates` if the provided
+    /// `ConstantRateDurations` have incommensurate sampling rates.
     pub fn try_saturating_sub_assign(&mut self, crd: ConstantRateDuration) -> Result<(), Error> {
         if self.rate == crd.rate {
             self.count = self.count.saturating_sub(crd.count);
@@ -842,16 +876,16 @@ mod constant_rate_duration {
             Ok(ConstantRateDuration::new(1, 48000))
         );
 
-        let c = ConstantRateDuration::new(10, 48000);
-        let d = ConstantRateDuration::new(1, 48000);
+        let a = ConstantRateDuration::new(10, 48000);
+        let b = ConstantRateDuration::new(1, 48000);
         assert_eq!(
-            d.try_saturating_sub(c),
+            b.try_saturating_sub(a),
             Ok(ConstantRateDuration::new(0, 48000))
         );
 
-        let e = ConstantRateDuration::new(96000, 96000);
-        let f = ConstantRateDuration::new(48000, 48000);
-        assert_eq!(e.try_saturating_sub(f), Err(Error::IncommensurateRates));
+        let a = ConstantRateDuration::new(96000, 96000);
+        let b = ConstantRateDuration::new(48000, 48000);
+        assert_eq!(a.try_saturating_sub(b), Err(Error::IncommensurateRates));
     }
 
     #[test]
@@ -862,15 +896,15 @@ mod constant_rate_duration {
         assert!(a.try_saturating_sub_assign(b).is_ok());
         assert_eq!(a.subsec_samples(), 8);
 
-        let mut c = ConstantRateDuration::new(1, 48000);
-        let d = ConstantRateDuration::new(5, 48000);
+        let mut a = ConstantRateDuration::new(1, 48000);
+        let b = ConstantRateDuration::new(5, 48000);
 
-        assert!(c.try_saturating_sub_assign(d).is_ok());
-        assert_eq!(c.subsec_samples(), 0);
+        assert!(a.try_saturating_sub_assign(b).is_ok());
+        assert_eq!(a.subsec_samples(), 0);
 
-        let mut _e = ConstantRateDuration::new(96000, 96000);
-        let f = ConstantRateDuration::new(48000, 48000);
-        assert!(_e.try_saturating_sub(f).is_err());
+        let a = ConstantRateDuration::new(96000, 96000);
+        let b = ConstantRateDuration::new(48000, 48000);
+        assert!(a.try_saturating_sub(b).is_err());
     }
 }
 
@@ -921,6 +955,7 @@ impl MixedRateDuration {
     ///
     /// assert_eq!(mrd.to_string(), "00:00:00");
     ///```
+    #[must_use]
     pub fn new() -> MixedRateDuration {
         MixedRateDuration {
             duration: Duration::new(0, 0),
@@ -945,6 +980,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.as_secs(), 62);
     /// ```
     /// [`subsec_secs`]: MixedRateDuration::subsec_secs
+    #[must_use]
     pub fn as_secs(&self) -> u64 {
         self.duration.as_secs()
     }
@@ -964,6 +1000,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "01:31:00;0");
     /// assert_eq!(mrd.as_mins(), 91);
     /// ```
+    #[must_use]
     pub fn as_mins(&self) -> u64 {
         self.as_secs() / SECS_PER_MIN
     }
@@ -983,6 +1020,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "48:00:00;12345");
     /// assert_eq!(mrd.as_hours(), 48);
     /// ```
+    #[must_use]
     pub fn as_hours(&self) -> u64 {
         self.as_secs() / SECS_PER_HOUR
     }
@@ -1002,6 +1040,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "48:00:00;12345");
     /// assert_eq!(mrd.as_days(), 2);
     /// ```
+    #[must_use]
     pub fn as_days(&self) -> u64 {
         self.as_secs() / SECS_PER_DAY
     }
@@ -1021,6 +1060,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "504:00:00;12345");
     /// assert_eq!(mrd.as_weeks(), 3);
     /// ```
+    #[must_use]
     pub fn as_weeks(&self) -> u64 {
         self.as_secs() / SECS_PER_WEEK
     }
@@ -1046,6 +1086,7 @@ impl MixedRateDuration {
     /// mrd += ConstantRateDuration::new(2, 44100);
     /// assert_eq!(mrd.num_rates(), 3);
     /// ```
+    #[must_use]
     pub fn num_rates(&self) -> usize {
         self.map.len()
     }
@@ -1065,6 +1106,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "00:00:01;24000");
     /// assert_eq!(mrd.subsec_nanos(), 500_000_000);
     /// ```
+    #[must_use]
     pub fn subsec_nanos(&self) -> u32 {
         let nanos_as_f64 = self.subsec_secs() * NANOS_PER_SEC;
 
@@ -1086,8 +1128,9 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "00:00:01;24000");
     /// assert_eq!(mrd.subsec_secs(), 0.5);
     /// ```
+    #[must_use]
     pub fn subsec_secs(&self) -> f64 {
-        self.duration.subsec_nanos() as f64 / NANOS_PER_SEC
+        f64::from(self.duration.subsec_nanos()) / NANOS_PER_SEC
     }
 
     /// Returns the _whole_ number of seconds left over when this
@@ -1105,6 +1148,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "00:01:05;32000");
     /// assert_eq!(mrd.submin_secs(), 5);
     /// ```
+    #[must_use]
     pub fn submin_secs(&self) -> u64 {
         self.as_secs() % SECS_PER_MIN
     }
@@ -1123,6 +1167,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "01:08:00;0");
     /// assert_eq!(mrd.subhour_mins(), 8);
     /// ```
+    #[must_use]
     pub fn subhour_mins(&self) -> u64 {
         self.as_mins() % MINS_PER_HOUR
     }
@@ -1141,6 +1186,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "25:00:00;0");
     /// assert_eq!(mrd.subday_hours(), 1);
     /// ```
+    #[must_use]
     pub fn subday_hours(&self) -> u64 {
         self.as_hours() % HOURS_PER_DAY
     }
@@ -1159,6 +1205,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "216:00:00;0");
     /// assert_eq!(mrd.subweek_days(), 2);
     /// ```
+    #[must_use]
     pub fn subweek_days(&self) -> u64 {
         self.as_days() % DAYS_PER_WEEK
     }
@@ -1175,6 +1222,7 @@ impl MixedRateDuration {
     /// assert_eq!(mrd.to_string(), "00:00:42;0");
     /// assert_eq!(mrd.to_duration().as_secs_f64(), 42.0);
     /// ```
+    #[must_use]
     pub fn to_duration(&self) -> Duration {
         self.duration
     }
@@ -1612,7 +1660,12 @@ mod mixed_rate_duration {
     #[should_panic(expected = "divide by zero when dividing a MixedRateDuration")]
     fn div_by_zero() {
         let a = MixedRateDuration::from(ConstantRateDuration::new(48000, 48000));
-        let _ = a / 0;
+        let b = a / 0;
+
+        unreachable!(
+            "The above line should have caused a divide by zero error and b={} should be NaN.",
+            b
+        );
     }
 
     #[test]
@@ -1654,7 +1707,12 @@ mod mixed_rate_duration {
     fn mul_overflow() {
         // Multiply MixedRateDurations which overflows
         let a = MixedRateDuration::from(ConstantRateDuration::new(u64::MAX, 48000));
-        let _ = a * 2;
+        let b = a * 2;
+
+        unreachable!(
+            "The above line should have caused an overflow and b={} should have overflown.",
+            b
+        );
     }
 
     #[test]
